@@ -27,4 +27,7 @@
 #define LOCALEDIR "/usr/share/locale"
 #define PACKAGE   "gpxview"
 
+// for osm-gps-map:
+#define USE_CAIRO
+
 #endif // CONFIG_H
