@@ -196,6 +196,14 @@ typedef struct {
 #else
   GtkWidget *window;
 #endif
+
+#ifdef ENABLE_OSM_GPS_MAP
+  struct {
+    int zoom;
+    pos_t pos;
+  } map;
+#endif
+
   GtkWidget *vbox;    
 } appdata_t;
 
