@@ -1029,12 +1029,25 @@ static void gpxlist_add(appdata_t *appdata, gpx_t *new) {
 
 /******************** begin of menu *********************/
 
+typedef struct {
+  appdata_t *appdata;
+  GtkWidget *dialog;
+} about_context_t;
+
+#ifdef ENABLE_BROWSER_INTERFACE
+void on_paypal_button_clicked(GtkButton *button, about_context_t *context) {
+  gtk_dialog_response(GTK_DIALOG(context->dialog), GTK_RESPONSE_ACCEPT); 
+  browser_url(context->appdata, 
+	      "https://www.paypal.com/cgi-bin/webscr"
+	      "?cmd=_s-xclick&hosted_button_id=7400558");
+}
+#endif
+
 static void 
 cb_menu_about(GtkWidget *window, gpointer data) {
-  GtkAboutDialog *about = GTK_ABOUT_DIALOG(gtk_about_dialog_new());
+  about_context_t context;
 
-  gtk_about_dialog_set_name(about, "GPXView");
-  gtk_about_dialog_set_version(about, VERSION);
+  context.appdata = (appdata_t *)data;
 
 #ifdef ENABLE_LIBLOCATION
   char *uses = "uses liblocation";
@@ -1044,25 +1057,46 @@ cb_menu_about(GtkWidget *window, gpointer data) {
   char *uses = "uses gpsd";
 #endif
   
-  char *str = g_strdup_printf("%s\n\n(%s)", 
-		      _("GPXView (c) 2008-2009 by\n" 
-			"Till Harbaum <till@harbaum.org>\n"
-			"Mailing list: gpxview-users@garage.maemo.org"),
-		      _(uses)
-		      );
+  const gchar *authors[] = {
+    "Till Harbaum <till@harbaum.org>",
+    "John Stowers <john.stowers@gmail.com>",
+    NULL };
 
-  gtk_about_dialog_set_copyright(about, str);
-  g_free(str);
+  context.dialog = g_object_new(GTK_TYPE_ABOUT_DIALOG,
+			"name", "GPXView",
+			"version", VERSION,
+			"copyright", _("Copyright 2008-2009"),
+			"authors", authors,		
+			"website", _("http://www.harbaum.org/till/maemo"),
+			"comments", _(uses),
+			NULL);
 
-  gtk_about_dialog_set_website(about,
-       _("http://www.harbaum.org/till/maemo"));
+#ifdef ENABLE_BROWSER_INTERFACE
+  /* add a way to donate to the project */
+  GtkWidget *alignment = gtk_alignment_new(0.5, 0, 0, 0);
   
-  gtk_about_dialog_set_comments(about, 
-       _("Geocaching.com GPX file viewer"));
+  GtkWidget *hbox = gtk_hbox_new(FALSE, 8);
+  gtk_box_pack_start(GTK_BOX(hbox),
+		     gtk_label_new(_("Do you you ĺike GPXView?")), 
+		     FALSE, FALSE, 0);
 
-  gtk_widget_show_all(GTK_WIDGET(about));
-  gtk_dialog_run(GTK_DIALOG(about));
-  gtk_widget_destroy(GTK_WIDGET(about));
+  GtkWidget *button = gtk_button_new();
+  gtk_button_set_image(GTK_BUTTON(button), 
+		       icon_get_widget(ICON_MISC, 8));
+  gtk_button_set_relief(GTK_BUTTON(button), GTK_RELIEF_NONE);
+  g_signal_connect(button, "clicked", 
+		   G_CALLBACK(on_paypal_button_clicked), &context); 
+  gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE, 0);
+
+  gtk_container_add(GTK_CONTAINER(alignment), hbox);
+  gtk_box_pack_start_defaults(GTK_BOX((GTK_DIALOG(context.dialog))->vbox),
+			      alignment);
+
+  gtk_widget_show_all(alignment);
+#endif
+
+  gtk_dialog_run(GTK_DIALOG(context.dialog));
+  gtk_widget_destroy(context.dialog);
 }
 
 #if defined(USE_MAEMO) && defined(HILDON_HELP)
