@@ -159,6 +159,11 @@ static void on_location_edit(GtkWidget *button, location_context_t *context) {
   if(loc) pos = loc->pos;
   else    pos = context->appdata->home;
 
+  /* avoid to use "nan" as the user will then not be displayed a nice */
+  /* preset value to alter */
+  if(isnan(pos.lat)) pos.lat = 0;
+  if(isnan(pos.lon)) pos.lon = 0;
+
   gtk_table_attach_defaults(GTK_TABLE(table),
 		   label = gtk_label_new(_("Latitude:")), 0, 1, 1, 2);
   gtk_misc_set_alignment(GTK_MISC(label), 1.f, 0.5f);
